@@ -1,5 +1,5 @@
-from .discord_api import DiscordAPI
-from .canvas_api import CanvasAPI
+from capstone_api.discord_api import DiscordAPI
+from capstone_api.canvas_api import CanvasAPI
 import argparse
 import sys
 
